@@ -1,13 +1,14 @@
 import logging
 
 from notecoin.database.base import create_all, session
-from notecoin.okex.websocket.dataset import OkexSocketPublicTickers
+from notecoin.okex.database.websocket import OkexSocketPublicTickers
 from notecoin.okex.websocket.utils import get_local_timestamp
 
 
 class BaseHandle:
     def __init__(self, channels, *args, **kwargs):
         self.channels = channels
+
     def solve(self, data) -> bool:
         data = eval(data)
 
