@@ -9,7 +9,8 @@ from notecoin.strategy.domain import OkexCoin
 
 
 class AutoSeller(RedisConnect):
-    def __init__(self, prefix="/sell",  *args, **kwargs):
+    def __init__(self, prefix="/sell", *args, **kwargs):
+        self.total = 0
         self.usdt = 0
         self.coin_map = {}
         super(AutoSeller, self).__init__(prefix=prefix, *args, **kwargs)
@@ -20,8 +21,10 @@ class AutoSeller(RedisConnect):
         details = session.query(OkexClientAccountBalance).filter(OkexClientAccountBalance.eqUsd > 10).all()
         for _detail in details:
             detail = _detail.json()
+
             if detail['ccy'] == 'USDT':
                 self.usdt = float(detail['availBal'])
+                self.total = self.usdt
                 continue
             coin = OkexCoin.instance_by_account(detail)
             if coin.money > 1:
@@ -30,11 +33,14 @@ class AutoSeller(RedisConnect):
     def update_price(self):
         data = json.loads(market_tickers.get_value().to_json(orient="records"))
         data_map = dict([(cin['instId'], cin['last']) for cin in data])
+        self.total = self.usdt
         for coin in self.coin_map.values():
             coin.price = float(data_map[coin.coin_id])
+            self.total += coin.money
 
     def to_json(self):
         return {
+            "total": self.total,
             "res": round(self.usdt, 2),
             "coins": [coin.to_json() for coin in self.coin_map.values()]
         }
@@ -45,9 +51,5 @@ class AutoSeller(RedisConnect):
         self.update_price()
         for coin in self.coin_map.values():
             coin.watch()
-            print(coin.coin_id)
+
         return self.to_json()
-
-
-# auto = AutoSeller()
-# auto.update_value()
